@@ -3,6 +3,8 @@
 compas_plotters
 ********************************************************************************
 
+2D visualization framework based on ``matplotlib`` for COMPAS geometry objects and data structures.
+
 .. currentmodule:: compas_plotters
 
 Classes
@@ -12,26 +14,21 @@ Classes
     :toctree: generated/
     :nosignatures:
 
-    GeometryPlotter
-    NetworkPlotter
-    MeshPlotter
-
+    Plotter
 
 """
 
-__version__ = '1.6.3'
+__version__ = '1.9.2'
 
 from .core import *  # noqa: F401 F403
-from .artists import *  # noqa: F401 F403
-
-from .geometryplotter import GeometryPlotter
-from .plotter import Plotter  # noqa: F401
-from .networkplotter import NetworkPlotter
-from .meshplotter import MeshPlotter
+# from .artists import *  # noqa: F401 F403
+from .plotter import Plotter
 
 
 __all__ = [
-    'GeometryPlotter',
-    'NetworkPlotter',
-    'MeshPlotter'
+    'Plotter'
+]
+
+__all_plugins__ = [
+    'compas_plotters.artists',
 ]
